@@ -43,6 +43,7 @@ from .entities import (
     MonitoringConfig,
     NeuroAuthConfig,
     NodePool,
+    NodePoolTemplate,
     NodeRole,
     OnPremCloudProvider,
     OpenStackCredentials,
@@ -142,9 +143,9 @@ class EntityFactory:
             idle_size=payload.get("idle_size", ResourcePoolType.idle_size),
             cpu=payload.get("cpu", ResourcePoolType.cpu),
             available_cpu=payload.get("available_cpu", ResourcePoolType.available_cpu),
-            memory_mb=payload.get("memory_mb", ResourcePoolType.memory_mb),
-            available_memory_mb=payload.get(
-                "available_memory_mb", ResourcePoolType.available_memory_mb
+            memory=payload.get("memory", ResourcePoolType.memory),
+            available_memory=payload.get(
+                "available_memory", ResourcePoolType.available_memory
             ),
             gpu=payload.get("gpu"),
             gpu_model=payload.get("gpu_model"),
@@ -171,7 +172,7 @@ class EntityFactory:
             name=payload["name"],
             credits_per_hour=Decimal(payload["credits_per_hour"]),
             cpu=payload["cpu"],
-            memory_mb=payload["memory_mb"],
+            memory=payload["memory"],
             gpu=payload.get("gpu"),
             gpu_model=payload.get("gpu_model"),
             tpu=tpu,
@@ -201,7 +202,7 @@ class EntityFactory:
     def create_resources(self, payload: dict[str, Any]) -> Resources:
         return Resources(
             cpu_m=payload["cpu_m"],
-            memory_mb=payload["memory_mb"],
+            memory=payload["memory"],
             gpu=payload.get("gpu", 0),
         )
 
@@ -212,7 +213,7 @@ class EntityFactory:
         )
 
     def create_volume(self, payload: dict[str, Any]) -> VolumeConfig:
-        return VolumeConfig(path=payload.get("path"), size_mb=payload.get("size_mb"))
+        return VolumeConfig(path=payload.get("path"), size=payload.get("size"))
 
     def create_registry(self, payload: dict[str, Any]) -> RegistryConfig:
         return RegistryConfig(url=URL(payload["url"]))
@@ -246,7 +247,7 @@ class EntityFactory:
     def create_disks(self, payload: dict[str, Any]) -> DisksConfig:
         return DisksConfig(
             url=URL(payload["url"]),
-            storage_limit_per_user_gb=payload["storage_limit_per_user_gb"],
+            storage_limit_per_user=payload["storage_limit_per_user"],
         )
 
     def create_buckets(self, payload: dict[str, Any]) -> BucketsConfig:
@@ -285,29 +286,45 @@ class EntityFactory:
                 access_key_id=credentials["access_key_id"],
                 secret_access_key=credentials["secret_access_key"],
             ),
-            node_pools=[self._create_node_pool(p) for p in payload["node_pools"]],
+            node_pools=[self.create_node_pool(p) for p in payload["node_pools"]],
             storage=self._create_aws_storage(payload["storage"]),
         )
 
-    def _create_node_pool(self, payload: dict[str, Any]) -> NodePool:
+    def create_node_pool(self, payload: dict[str, Any]) -> NodePool:
+        price = Decimal(payload["price"]) if payload.get("price") else NodePool.price
         return NodePool(
             name=payload["name"],
+            id=payload.get("id"),
             role=NodeRole(payload["role"]),
             min_size=payload["min_size"],
             max_size=payload["max_size"],
-            cpu=payload["cpu"],
-            available_cpu=payload["available_cpu"],
-            memory_mb=payload["memory_mb"],
-            available_memory_mb=payload["available_memory_mb"],
-            disk_size_gb=payload.get("disk_size_gb", NodePool.disk_size_gb),
+            cpu=payload.get("cpu"),
+            available_cpu=payload.get("available_cpu"),
+            memory=payload.get("memory"),
+            available_memory=payload.get("available_memory"),
+            disk_size=payload.get("disk_size", NodePool.disk_size),
             disk_type=payload.get("disk_type", NodePool.disk_type),
             gpu=payload.get("gpu"),
             gpu_model=payload.get("gpu_model"),
-            price=Decimal(payload.get("price", NodePool.price)),
+            price=price,
             currency=payload.get("currency", NodePool.currency),
             machine_type=payload.get("machine_type"),
             idle_size=payload.get("idle_size", NodePool.idle_size),
             is_preemptible=payload.get("is_preemptible", NodePool.is_preemptible),
+            zones=payload.get("zones", NodePool.zones),
+        )
+
+    @staticmethod
+    def create_node_pool_template(payload: dict[str, Any]) -> NodePoolTemplate:
+        return NodePoolTemplate(
+            id=payload["id"],
+            machine_type=payload["machine_type"],
+            cpu=payload["cpu"],
+            available_cpu=payload["available_cpu"],
+            memory=payload["memory"],
+            available_memory=payload["available_memory"],
+            gpu=payload.get("gpu"),
+            gpu_model=payload.get("gpu_model"),
         )
 
     def _create_aws_storage(self, payload: dict[str, Any]) -> AWSStorage:
@@ -328,7 +345,7 @@ class EntityFactory:
             project=payload["project"],
             credentials=payload["credentials"],
             tpu_enabled=payload.get("tpu_enabled", False),
-            node_pools=[self._create_node_pool(p) for p in payload["node_pools"]],
+            node_pools=[self.create_node_pool(p) for p in payload["node_pools"]],
             storage=self._create_google_storage(payload["storage"]),
         )
 
@@ -353,7 +370,7 @@ class EntityFactory:
                 client_id=credentials["client_id"],
                 client_secret=credentials["client_secret"],
             ),
-            node_pools=[self._create_node_pool(p) for p in payload["node_pools"]],
+            node_pools=[self.create_node_pool(p) for p in payload["node_pools"]],
             storage=self._create_azure_storage(payload["storage"]),
         )
 
@@ -386,7 +403,7 @@ class EntityFactory:
                 URL(payload["kubernetes_url"]) if "kubernetes_url" in payload else None
             ),
             credentials=credentials,
-            node_pools=[self._create_node_pool(p) for p in payload["node_pools"]],
+            node_pools=[self.create_node_pool(p) for p in payload["node_pools"]],
             storage=None,
         )
 
@@ -409,7 +426,7 @@ class EntityFactory:
                 password=credentials["password"],
                 ssh_password=credentials.get("ssh_password"),
             ),
-            node_pools=[self._create_node_pool(p) for p in payload["node_pools"]],
+            node_pools=[self.create_node_pool(p) for p in payload["node_pools"]],
             storage=self._create_vcd_storage(payload["storage"]),
         )
 
@@ -417,7 +434,7 @@ class EntityFactory:
         result = VCDStorage(
             description=payload["description"],
             profile_name=payload["profile_name"],
-            size_gib=payload["size_gib"],
+            size=payload["size"],
             instances=[self._create_storage_instance(p) for p in payload["instances"]],
         )
         return result
@@ -425,7 +442,7 @@ class EntityFactory:
     def _create_storage_instance(self, payload: dict[str, Any]) -> StorageInstance:
         return StorageInstance(
             name=payload.get("name"),
-            size_mb=payload.get("size_mb"),
+            size=payload.get("size"),
             ready=payload["ready"],
         )
 
@@ -636,8 +653,8 @@ class PayloadFactory:
         result: dict[str, Any] = {}
         if volume.path:
             result["path"] = volume.path
-        if volume.size_mb is not None:
-            result["size_mb"] = volume.size_mb
+        if volume.size is not None:
+            result["size"] = volume.size
         return result
 
     @classmethod
@@ -692,9 +709,9 @@ class PayloadFactory:
             "idle_size": resource_pool_type.idle_size,
             "cpu": resource_pool_type.cpu,
             "available_cpu": resource_pool_type.available_cpu,
-            "memory_mb": resource_pool_type.memory_mb,
-            "available_memory_mb": resource_pool_type.available_memory_mb,
-            "disk_size_gb": resource_pool_type.disk_size_gb,
+            "memory": resource_pool_type.memory,
+            "available_memory": resource_pool_type.available_memory,
+            "disk_size": resource_pool_type.disk_size,
         }
         if resource_pool_type.gpu:
             result["gpu"] = resource_pool_type.gpu
@@ -720,7 +737,7 @@ class PayloadFactory:
             "name": preset.name,
             "credits_per_hour": str(preset.credits_per_hour),
             "cpu": preset.cpu,
-            "memory_mb": preset.memory_mb,
+            "memory": preset.memory,
         }
         if preset.gpu:
             result["gpu"] = preset.gpu
@@ -759,7 +776,7 @@ class PayloadFactory:
 
     @classmethod
     def _create_resources(cls, resources: Resources) -> dict[str, Any]:
-        result = {"cpu_m": resources.cpu_m, "memory_mb": resources.memory_mb}
+        result = {"cpu_m": resources.cpu_m, "memory": resources.memory}
         if resources.gpu:
             result["gpu"] = resources.gpu
         return result
@@ -805,7 +822,7 @@ class PayloadFactory:
     def create_disks(cls, disks: DisksConfig) -> dict[str, Any]:
         return {
             "url": str(disks.url),
-            "storage_limit_per_user_gb": disks.storage_limit_per_user_gb,
+            "storage_limit_per_user": disks.storage_limit_per_user,
         }
 
     @classmethod
@@ -814,3 +831,44 @@ class PayloadFactory:
         if ingress.cors_origins:
             result["cors_origins"] = ingress.cors_origins
         return result
+
+    @classmethod
+    def create_node_pool(cls, node_pool: NodePool) -> dict[str, Any]:
+        node_pool
+        result = {
+            "name": node_pool.name,
+            "role": node_pool.role.value,
+            "min_size": node_pool.min_size,
+            "max_size": node_pool.max_size,
+        }
+        if node_pool.id:
+            result["id"] = node_pool.id
+        if node_pool.idle_size:
+            result["idle_size"] = node_pool.idle_size
+        if node_pool.machine_type:
+            result["machine_type"] = node_pool.machine_type
+        if node_pool.cpu:
+            result["cpu"] = node_pool.cpu
+        if node_pool.available_cpu:
+            result["available_cpu"] = node_pool.available_cpu
+        if node_pool.memory:
+            result["memory"] = node_pool.memory
+        if node_pool.available_memory:
+            result["available_memory"] = node_pool.available_memory
+        if node_pool.disk_size:
+            result["disk_size"] = node_pool.disk_size
+        if node_pool.disk_type:
+            result["disk_type"] = node_pool.disk_type
+        if node_pool.gpu:
+            result["gpu"] = node_pool.gpu
+        if node_pool.gpu_model:
+            result["gpu_model"] = node_pool.gpu_model
+        if node_pool.price:
+            result["price"] = str(node_pool.price)
+        if node_pool.currency:
+            result["currency"] = node_pool.currency
+        if node_pool.is_preemptible:
+            result["is_preemptible"] = node_pool.is_preemptible
+        if node_pool.zones:
+            result["zones"] = node_pool.zones
+        return result
